@@ -1,8 +1,11 @@
+from audioop import add
 from urllib.parse import quote
+from webbrowser import open_new_tab
+from enum import Enum, unique
 
 
-# Engines are listed in alphabetical order and the UpperCamelCase convention
-class Engine:
+@unique
+class Engine(Enum):
     Apple = "https://www.apple.com/search/{query}"
     Ask = "https://www.ask.com/web?q={query}"
     AOL = "https://search.aol.com/aol/search?q={query}"
@@ -23,6 +26,7 @@ class Engine:
     FedEx = "https://www.fedex.com/en-us/search.html?q={query}"
     G2 = "https://www.g2.com/search?query={query}"
     GitHub = "https://www.github.com/search?q={query}"
+    GitLab = "https://www.gitlab.com/search?search={query}"
     Google = "https://www.google.com/search?q={query}"
     Genius = "https://www.genius.com/search?q={query}"
     InstantGaming = "https://www.instant-gaming.com/en/search/?q={query}"
@@ -57,17 +61,13 @@ class Engine:
     Yahoo = "https://search.yahoo.com/search?p={query}"
     Yandex = "https://yandex.com/search/?text={query}"
 
-
-# search function
-def search(query, engine=Engine.Google):
-    return engine.format(query=quote(query, safe=""))
-
-
-# returns all the engines available
-def engine_list():
-    members = [
-        attr
-        for attr in dir(Engine)
-        if not callable(getattr(Engine, attr)) and not attr.startswith("__")
-    ]
-    return members
+    def search(self, query, open_web=False, additional_queries: dict = None):
+        url = self.value.format(query=quote(query, safe=""))
+        if additional_queries:
+            url += ("?" if "?" not in self.value.split("/")[-1] else "&") + "&".join(
+                query + "=" + quote(query_val)
+                for query, query_val in additional_queries.items()
+            )
+        if open_web is True:
+            open_new_tab(url)
+        return url
